@@ -63,18 +63,16 @@ class DeepLearningNewsvendor(BaseNewsvendor, DataDrivenMixin):
 
     Examples
     --------
-    >>> from ddop.datasets.load_datasets import load_data
+    >>> from ddop.datasets import load_yaz
     >>> from ddop.newsvendor import DeepLearningNewsvendor
     >>> from sklearn.model_selection import train_test_split
-    >>> data = load_data("yaz_steak.csv")
-    >>> X = data.iloc[:,0:24]
-    >>> Y = data.iloc[:,24]
+    >>> X, Y = load_yaz(include_prod=['STEAK'],return_X_y=True)
     >>> cu,co = 15,10
-    >>> X_train, X_test, Y_train, Y_test = train_test_split(X, Y, test_size=0.25)
+    >>> X_train, X_test, Y_train, Y_test = train_test_split(X, Y, test_size=0.25, shuffle=False, random_state=0)
     >>> mdl = DeepLearningNewsvendor(cu, co)
     >>> mdl.fit(X_train, Y_train)
     >>> mdl.score(X_test, Y_test)
-    [64.62898917]
+    TODO: ADD SCORE
     """
 
     def __init__(self, cu, co, hidden_layers='auto', neurons=[100],
@@ -99,6 +97,7 @@ class DeepLearningNewsvendor(BaseNewsvendor, DataDrivenMixin):
         return customized_loss
 
     def _create_model(self):
+        """Create model"""
         hidden_layers = self.hidden_layers
         neurons = self.neurons
         activations = self.activations
@@ -159,6 +158,8 @@ class DeepLearningNewsvendor(BaseNewsvendor, DataDrivenMixin):
         return self
 
     def _validate_hyperparameters(self):
+        """validate hyperparameters"""
+
         # Make sure self.neurons is a list
         neurons = self.neurons
         if not hasattr(neurons, "__iter__"):
