@@ -19,9 +19,6 @@ class RandomForestNewsvendor(ForestRegressor):
 
     Parameters
     ----------
-    criterion : {"newsvendor"}, default="newsvendor"
-        The function to measure the quality of a split. Supported is only
-        "newsvendor", which minimizes the Loss-function described in [5]
     cu : {array-like of shape (n_outputs,), Number or None}, default=None
        The underage costs per unit. If None, then underage costs are one
        for each target variable
@@ -184,25 +181,21 @@ class RandomForestNewsvendor(ForestRegressor):
            Research 7.Jun (2006): 983-999.
      Examples
     --------
-    >>> from ddop.datasets.load_datasets import load_data
+    >>> from ddop.datasets import load_yaz
     >>> from ddop.newsvendor import RandomForestNewsvendor
-    >>> from ddop.metrics.costs import calc_avg_costs
     >>> from sklearn.model_selection import train_test_split
-    >>> data = load_data("yaz_steak.csv")
-    >>> X = data.iloc[:,0:24]
-    >>> Y = data.iloc[:,24]
+    >>> X, Y = load_yaz(include_prod=['STEAK'],return_X_y=True)
     >>> cu,co = 15,10
-    >>> X_train, X_test, Y_train, Y_test = train_test_split(X, Y, test_size=0.25)
+    >>> X_train, X_test, Y_train, Y_test = train_test_split(X, Y, test_size=0.25, shuffle=False, random_state=0)
     >>> mdl = RandomForestNewsvendor(cu, co, max_depth=5, random_state=0)
     >>> mdl.fit(X_train, Y_train)
     >>> score(X_test, Y_test)
-    [76.68421053]
+    TODO: ADD VALUE
     """
 
     def __init__(self,
                  cu=None,
                  co=None,
-                 criterion="NewsvendorCriterion",
                  n_estimators=100, *,
                  max_depth=None,
                  min_samples_split=2,
@@ -234,7 +227,7 @@ class RandomForestNewsvendor(ForestRegressor):
             verbose=verbose,
             warm_start=warm_start,
             max_samples=max_samples)
-        self.criterion = criterion
+        self.criterion = "NewsvendorCriterion"
         self.cu = cu
         self.co = co
         self.max_depth = max_depth
@@ -327,6 +320,23 @@ class RandomForestNewsvendor(ForestRegressor):
         return np.asarray(pred)
 
     def score(self, X, y, sample_weight=None):
+        """
+        Return the average costs of the prediction
+
+        Parameters
+        ----------
+        X : array-like of shape (n_samples, n_features)
+            The input samples to predict.
+        y : array-like of shape (n_samples, n_outputs)
+            The true values for x.
+        sample_weight: array-like of shape (n_samples)
+            Sample weights
+
+        Returns
+        -------
+         score: float
+            The average costs
+        """
         y_pred = self.predict(X)
         return calc_avg_costs(y, y_pred, self.cu_, self.co_)
 
